@@ -1,7 +1,7 @@
 package App::ListRevDeps;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -172,7 +172,7 @@ App::ListRevDeps - List reverse dependencies of a Perl module
 
 =head1 VERSION
 
-This document describes version 0.13 of App::ListRevDeps (from Perl distribution App-ListRevDeps), released on 2015-08-17.
+This document describes version 0.14 of App::ListRevDeps (from Perl distribution App-ListRevDeps), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -188,7 +188,7 @@ caches results for 24 hours.
 
 =head2 list_rev_deps(%args) -> [status, msg, result, meta]
 
-{en_US List reverse dependencies of a Perl module}.
+List reverse dependencies of a Perl module.
 
 Arguments ('*' denotes required arguments):
 
@@ -196,23 +196,23 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cache> => I<bool> (default: 1)
 
-{en_US Whether to cache API results for some time, for performance}.
+Whether to cache API results for some time, for performance.
 
 =item * B<exclude_re> => I<str>
 
-{en_US Specify dist pattern to exclude}.
+Specify dist pattern to exclude.
 
 =item * B<level> => I<int> (default: 1)
 
-{en_US Specify how many levels up to check (-1 means unlimited)}.
+Specify how many levels up to check (-1 means unlimited).
 
 =item * B<module>* => I<array>
 
-{en_US Perl module(s) to check}.
+Perl module(s) to check.
 
 =item * B<raw> => I<bool> (default: 0)
 
-{en_US Return raw result}.
+Return raw result.
 
 =back
 
